from settings import *  # flake8: noqa
INSTALLED_APPS.append('alphanumeric')

ROOT_URLCONF = 'alphanumeric.urls'
